@@ -9,12 +9,13 @@ def decode(tile):
     message = vector_tile.getMessage(tile)
     return message
 
-def encode(layers):
-    vector_tile = encoder.VectorTile(extents)
+def encode(layers, encode_floats_big_endian=True):
+    vector_tile = encoder.VectorTile(
+        extents, encode_floats_big_endian=encode_floats_big_endian)
     if (isinstance(layers, list)):
         for layer in layers:
             vector_tile.addFeatures(layer['features'], layer['name'])
     else:
         vector_tile.addFeatures(layers['features'], layers['name'])
 
-    return vector_tile.tile.SerializeToString()
\ No newline at end of file
+    return vector_tile.tile.SerializeToString()
